%define tarballname signing-party
%define debian_version 1.1
Name:           pgp-tools
Version:        1.1
Release:        4%{?dist}
Summary:        Collection of several utilities related to OpenPGP
Group:          Applications/System
License:        BSD and GPLv2+
URL:            http://pgp-tools.alioth.debian.org/
# To check out the source tree from subversion, use this:
# svn co svn://svn.debian.org/pgp-tools/trunk/ pgp-tools
# or to get a particular revision:
# svn co svn://svn.debian.org/pgp-tools/tags/release-%{version} signing-party-%{version}
# Then to make the tarball, use:
# tar cvzf signing-party_%{version}.orig.tar.gz --exclude=.svn --exclude=debian signing-party-%{version}/
# For some releases you may also find source tarballs posted at
# http://alioth.debian.org/project/showfiles.php?group_id=30435
# 
# svn co svn://svn.debian.org/pgp-tools/tags/debian-version-1.0-2 signing-party-%{version}
Source0:        %{tarballname}_%{debian_version}.orig.tar.gz
# from svn debian/copyright, not included in tarballs.
Source1:        copyright
Patch0:         %{name}-1.1-drop-pgpring.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
# for gpgdir test suite
BuildRequires:  gpg, perl(GnuPG::Interface), perl(Term::ReadKey), perl(Class::MethodMaker)
Requires:       gpg, perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires:       mktemp, sed, /usr/sbin/sendmail, perl(Locale::Recode)
Requires:       perl(Class::MethodMaker), perl(Term::ReadKey)
# for pgpring
Requires:      mutt


%description
This is a collection of several projects relating to OpenPGP.

* caff: CA - Fire and Forget signs and mails a key
* pgp-clean: removes all non-self signatures from key
* pgp-fixkey: removes broken packets from keys
* gpg-mailkeys: simply mail out a signed key to its owner
* gpg-key2ps: generate PostScript file with fingerprint paper strips
* gpgdir: recursive directory encryption tool
* gpglist: show who signed which of your UIDs
* gpgsigs: annotates list of GnuPG keys with already done signatures
* keylookup: ncurses wrapper around gpg --search
* gpgparticipants: create list of party participants for the organiser
* gpgwrap: a passphrase wrapper
* keyanalyze: minimum signing distance (MSD) analysis on keyrings
* sig2dot: converts a list of GnuPG signatures to a .dot file
* springgraph: creates a graph from a .dot file


%prep
%setup -q -n %{tarballname}-%{version}
cp %SOURCE1 .
# fix gpgdir library path lookup as we're using system-provided libraries
sed -i -e "s,/usr/lib/gpgdir,," gpgdir/gpgdir
%patch0 -p1

%build
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
make install DESTDIR=$RPM_BUILD_ROOT || :
# apps with no 'make install'
for f in caff pgp-clean pgp-fixkey ; do
install -m 755 caff/$f $RPM_BUILD_ROOT%{_bindir}/
done
install -m 755 gpg-key2ps/gpg-key2ps $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpgdir/gpgdir $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpglist/gpglist $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpgwrap/bin/gpgwrap $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpg-mailkeys/gpg-mailkeys $RPM_BUILD_ROOT%{_bindir}/
install -m 755 gpgparticipants/gpgparticipants $RPM_BUILD_ROOT%{_bindir}/

# nuke apps creating their own docs dir
rm -rf ${RPM_BUILD_ROOT}/usr/share/doc
# find all manpages wherever they are hiding
DIRS="$(find . -maxdepth 1 -type d | sed -e 's:^.$::' -e 's:^./::')"
for man in `find $DIRS -type f -name "*.1" -print`
do
    install -m644 $man $RPM_BUILD_ROOT%{_mandir}/man1
done

# nuke our copy of pgpring manpage
rm ${RPM_BUILD_ROOT}/%{_mandir}/man1/pgpring.1


rm -rf __fedora_docs
mkdir __fedora_docs
cp -a $DIRS __fedora_docs/

#  cleanup to leave docs only...
find __fedora_docs/ -type f \( -perm +0111 -o -name Makefile -o -name "*.[1-9]" \) -print | xargs rm -f
find __fedora_docs -type d -name src -exec rm -rf \{\} \; || :
rm -rf __fedora_docs/keyanalyze/pgpring
rm -rf __fedora_docs/keyanalyze/*.[cho]
rm     __fedora_docs/gpgdir/INSTALL
rm -rf __fedora_docs/gpgdir/packaging
rm -rf __fedora_docs/gpgdir/test
rm -rf __fedora_docs/gpgwrap/{bin,doc}
rm -rf __fedora_docs/gpglist
rm -rf __fedora_docs/gpgparticipants
mv __fedora_docs/keylookup/COPYING .


%check
pushd gpgdir/test
./gpgdir_test.pl
RC=0
grep "STATUS: fail" output/*.test > /dev/null 2>&1 && RC=1
popd
exit $RC

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/signing-party
%doc README COPYING copyright
%doc __fedora_docs/*

%changelog
* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.1-4
- rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Apr 17 2009 Matt Domsch <mdomsch@fedoraproject.org> - 1.1-2
- add BRs so %%check succeeds
- drop upstream's outdated copy of pgpring. mutt provides a newer
  version, so require mutt.

* Fri Apr 17 2009 Matt Domsch <mdomsch@fedoraproject.org> - 1.1-1
- update to 1.1
  adds gpgdir, gpgwrap, keyanalyze

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue May 20 2008 Matt Domsch <Matt_Domsch@dell.com> 1.0-1
- upgrade to 1.0-1
  - gpgsigs: Implement support for LaTeX output and photo ids.
    (Closes: debian #412433, #430607)
  - gpg-key2ps: Mention http://www.debian.org/events/materials/business-cards/
    as an alternative. (Closes: debian #439510)
  - add sig2dot and springgraph

* Tue Feb  5 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.4.12-2
- rebuild for new perl (and fix license tag)

* Wed Sep 19 2007 Matt Domsch <Matt_Domsch@dell.com> 0.4.12-1
- upgrade to 0.4.12
- cleanup doc installation (BZ#246433)

* Thu Nov 02 2006 Matt Domsch <Matt_Domsch@dell.com> 0.4.9-1
- upgrade to 0.4.9
  - Fix a bug with checking if we have exactly one or more keys that failed downloading.
  - Mention in manpage that keyserver-options is a useful setting in
    .caff/gnupghome/gpg.conf (Closes: debian #392811).
  - q-p-encode From: header (Closes: debian #366745).

* Sat Oct 07 2006 Matt Domsch <Matt_Domsch@dell.com> 0.4.8-1
- upgrade to 0.4.8
  - gpglist: do not die with with-fingerprint (Closes: debian #382019).
  - gpg-key2ps: add --list-key to gpg call (works around debian #382794).
  - caff: when set, use $ENV{'GNUPGHOME'} to find secring.gpg. Suggested by
    Gerfried Fuchs.

* Mon Jul 10 2006 Matt Domsch <Matt_Domsch@dell.com> 0.4.7-1
- upgrade to latest upstream
  - gpg-mailkeys: use right content-type for attached key,
    thanks Wesley Landaker (Closes: debian #370566).
  - upstream releasing tarballs now, so use those

* Thu May 25 2006 Matt Domsch <Matt_Domsch@dell.com> 0.4.6-1.20060525svn
- upgrade to lastest upstream

* Sun Feb 12 2006 Matt Domsch <Matt_Domsch@dell.com> 0.4.4-3.20060212svn
- upgrade to lastest upstream
- rebuild for FC5

* Tue Nov 29 2005 Matt Domsch <Matt_Domsch@dell.com> 0.4.4-3.20051123svn
- require perl(Locale::Recode) for gpgsigs

* Mon Nov 28 2005 Matt Domsch <Matt_Domsch@dell.com> 0.4.4-2.20051123svn
- cleanups based on feedback from dmitry@butskoy.name

* Thu Nov 10 2005 Matt Domsch <Matt_Domsch@dell.com> 0.4.4-1
- initial release
